<!--- 
	csw-image-textblock-carousel-generic-rh.cfm

	This 'generic' render handler render handler implements the 'getGenericFieldMappingsArray' function below to describe
	the available field that can be mapped.

	The logic above the function, renders an image with a caption above it, and optionally renders a description
	and link.

	Note that for 'generic' render handlers the mapped data, if any, will always be passed in the following structure:
		Attributes.ElementInfo.ElementData.PropertyValues
	This is an array of one or more items, with a sub-structure named 'values'.
	Values is a structure with members as defined by the getGenericFieldMappingsArray() function.

	This generic render handler assumes these fields:
		- Title - Required
		- Description - Required
		- Image (string or struct)
		- LinkURL  (string or struct)
		- LinkText  (string)
	
	Version: [2018-01-17 10:00]
--->
<cfscript>
	// Create the Image Textblock Carousel Component
	csWidget = CreateObject('component','_cs_widgets.csw-imagetextblock-carousel.renderhandlers.csw-image-textblock-carousel');
	
	// load necessary resources
	csWidget.loadResources(); 
	
	// exit if all we're doing is detecting required resources
	if ( Request.RenderState.RenderMode EQ "getResources" )
		exit;

	if ( NOT structKeyExists(attributes,'elementinfo') )
		exit;
		
	// Load the Properties from the metadata form		
	props = csWidget.loadProperties(Attributes.ElementInfo,Variables.Caller);	
	
	// Make sure we have Props data
	if( NOT csWidget.hasProperties(props) )
		exit;
	
	// Get the element Data and Render the items
	if( StructKeyExists(Attributes.ElementInfo.ElementData, 'PropertyValues') )
		csWidget.getAndRenderItems( Attributes.ElementInfo.ElementData, props, request.element.id );
</cfscript>

<!--- ////////////////////////////////////////////////////////////////////////// --->
<!--- //////////////////   GENERIC RENDER HANDLER FUNCTIONS   ////////////////// --->
<!--- ////////////////////////////////////////////////////////////////////////// --->

<!---
	This is the function that is called by CommonSpot when this render handler is registred, allowing teh user to
	map the fields of the source element to this render handler.

	Here we expose build a structure describing the four (4) fields that can be mapped. Two (2) of the fields are marked
	as required. The other two are optional.
		- Title - Required
		- Image - Required
		- LinkURL - Optional (string or csExtURL structure)
		- LinkText - Optional (string)
		- Description - Optional
		
	Each fieldMappingArray item is a structure with the following 3 fields:
		- FieldName
		- Description
		- Required
--->
<cffunction name="getGenericFieldMappingsArray" returntype="array" access="private" output="no">
	<cfscript>
		var fieldMappingArray = ArrayNew(1);
		var fieldDetailsStruct = StructNew();

		// Image Properties
		// ------------------

		// Image (REQUIRED)
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Image';
		fieldDetailsStruct.Description = 'The image for the card.';
		fieldDetailsStruct.Required = 1;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);	

		// image position (focal point)
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'ImageFocalPoint';
		fieldDetailsStruct.Description = 'The CSS class that determines the focal point on the displayed image';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);
		
		
		// Title & Description
		// ----------------------		
		
		// title (REQUIRED)
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Title';
		fieldDetailsStruct.Description = 'The title text for the card.';
		fieldDetailsStruct.Required = 1;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);
		
		// description
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Description';
		fieldDetailsStruct.Description = 'The subtitle text for the image.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);				
		
				
		// --------------------------
		// Link/Button Properties
		// --------------------------

		// Link URL
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'LinkURL';
		fieldDetailsStruct.Description = 'The server relative URL associated with the slide or button.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Link Text
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'LinkText';
		fieldDetailsStruct.Description = 'Text to display for link/button.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Button Type
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Button_Type';
		fieldDetailsStruct.Description = 'The style of control to display, either a button or link. Can also include an icon on the left or right.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Button
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Button';
		fieldDetailsStruct.Description = 'JSON string that describes the appearance of the button (alignment, size, color, etc.)';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Button Corners
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Button_Corners';
		fieldDetailsStruct.Description = 'Style for button corners';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Link
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Link';
		fieldDetailsStruct.Description = 'JSON string that describes the appearance of the link (alignment, size, color, etc.)';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Icon
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Icon';
		fieldDetailsStruct.Description = 'The icon that will appear to the left or right of the button or link.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);
		
		
		return fieldMappingArray;
	</cfscript>
</cffunction>
		

